@@ -30,34 +30,34 @@ from .type_defs import (
     AvailSuppressionTypeDef,
     BumperTypeDef,
     CdnConfigurationTypeDef,
-    CreateChannelResponseTypeDef,
-    CreateProgramResponseTypeDef,
-    CreateSourceLocationResponseTypeDef,
-    CreateVodSourceResponseTypeDef,
+    CreateChannelResponseResponseTypeDef,
+    CreateProgramResponseResponseTypeDef,
+    CreateSourceLocationResponseResponseTypeDef,
+    CreateVodSourceResponseResponseTypeDef,
     DashConfigurationForPutTypeDef,
     DefaultSegmentDeliveryConfigurationTypeDef,
-    DescribeChannelResponseTypeDef,
-    DescribeProgramResponseTypeDef,
-    DescribeSourceLocationResponseTypeDef,
-    DescribeVodSourceResponseTypeDef,
-    GetChannelPolicyResponseTypeDef,
-    GetChannelScheduleResponseTypeDef,
-    GetPlaybackConfigurationResponseTypeDef,
+    DescribeChannelResponseResponseTypeDef,
+    DescribeProgramResponseResponseTypeDef,
+    DescribeSourceLocationResponseResponseTypeDef,
+    DescribeVodSourceResponseResponseTypeDef,
+    GetChannelPolicyResponseResponseTypeDef,
+    GetChannelScheduleResponseResponseTypeDef,
+    GetPlaybackConfigurationResponseResponseTypeDef,
     HttpConfigurationTypeDef,
     HttpPackageConfigurationTypeDef,
-    ListChannelsResponseTypeDef,
-    ListPlaybackConfigurationsResponseTypeDef,
-    ListSourceLocationsResponseTypeDef,
-    ListTagsForResourceResponseTypeDef,
-    ListVodSourcesResponseTypeDef,
+    ListChannelsResponseResponseTypeDef,
+    ListPlaybackConfigurationsResponseResponseTypeDef,
+    ListSourceLocationsResponseResponseTypeDef,
+    ListTagsForResourceResponseResponseTypeDef,
+    ListVodSourcesResponseResponseTypeDef,
     LivePreRollConfigurationTypeDef,
     ManifestProcessingRulesTypeDef,
-    PutPlaybackConfigurationResponseTypeDef,
+    PutPlaybackConfigurationResponseResponseTypeDef,
     RequestOutputItemTypeDef,
     ScheduleConfigurationTypeDef,
-    UpdateChannelResponseTypeDef,
-    UpdateSourceLocationResponseTypeDef,
-    UpdateVodSourceResponseTypeDef,
+    UpdateChannelResponseResponseTypeDef,
+    UpdateSourceLocationResponseResponseTypeDef,
+    UpdateVodSourceResponseResponseTypeDef,
 )
 
 if sys.version_info >= (3, 8):
@@ -84,7 +84,7 @@ class Exceptions:
 
 class MediaTailorClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/mediatailor.html#MediaTailor.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html)
     """
 
@@ -93,7 +93,9 @@ class MediaTailorClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/mediatailor.html#MediaTailor.Client.can_paginate)
+        Check if an operation can be paginated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#can_paginate)
         """
 
@@ -101,12 +103,14 @@ class MediaTailorClient:
         self,
         *,
         ChannelName: str,
-        Outputs: List[RequestOutputItemTypeDef],
+        Outputs: List["RequestOutputItemTypeDef"],
         PlaybackMode: Literal["LOOP"],
         Tags: Dict[str, str] = None
-    ) -> CreateChannelResponseTypeDef:
+    ) -> CreateChannelResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/mediatailor.html#MediaTailor.Client.create_channel)
+        Creates a channel.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Client.create_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#create_channel)
         """
 
@@ -115,13 +119,15 @@ class MediaTailorClient:
         *,
         ChannelName: str,
         ProgramName: str,
-        ScheduleConfiguration: ScheduleConfigurationTypeDef,
+        ScheduleConfiguration: "ScheduleConfigurationTypeDef",
         SourceLocationName: str,
         VodSourceName: str,
         AdBreaks: List["AdBreakTypeDef"] = None
-    ) -> CreateProgramResponseTypeDef:
+    ) -> CreateProgramResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/mediatailor.html#MediaTailor.Client.create_program)
+        Creates a program.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Client.create_program)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#create_program)
         """
 
@@ -133,9 +139,11 @@ class MediaTailorClient:
         AccessConfiguration: "AccessConfigurationTypeDef" = None,
         DefaultSegmentDeliveryConfiguration: "DefaultSegmentDeliveryConfigurationTypeDef" = None,
         Tags: Dict[str, str] = None
-    ) -> CreateSourceLocationResponseTypeDef:
+    ) -> CreateSourceLocationResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/mediatailor.html#MediaTailor.Client.create_source_location)
+        Creates a source location on a specific channel.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Client.create_source_location)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#create_source_location)
         """
 
@@ -146,75 +154,97 @@ class MediaTailorClient:
         SourceLocationName: str,
         VodSourceName: str,
         Tags: Dict[str, str] = None
-    ) -> CreateVodSourceResponseTypeDef:
+    ) -> CreateVodSourceResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/mediatailor.html#MediaTailor.Client.create_vod_source)
+        Creates name for a specific VOD source in a source location.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Client.create_vod_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#create_vod_source)
         """
 
     def delete_channel(self, *, ChannelName: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/mediatailor.html#MediaTailor.Client.delete_channel)
+        Deletes a channel.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Client.delete_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#delete_channel)
         """
 
     def delete_channel_policy(self, *, ChannelName: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/mediatailor.html#MediaTailor.Client.delete_channel_policy)
+        Deletes a channel's IAM policy.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Client.delete_channel_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#delete_channel_policy)
         """
 
     def delete_playback_configuration(self, *, Name: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/mediatailor.html#MediaTailor.Client.delete_playback_configuration)
+        Deletes the playback configuration for the specified name.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Client.delete_playback_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#delete_playback_configuration)
         """
 
     def delete_program(self, *, ChannelName: str, ProgramName: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/mediatailor.html#MediaTailor.Client.delete_program)
+        Deletes a specific program on a specific channel.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Client.delete_program)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#delete_program)
         """
 
     def delete_source_location(self, *, SourceLocationName: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/mediatailor.html#MediaTailor.Client.delete_source_location)
+        Deletes a source location on a specific channel.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Client.delete_source_location)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#delete_source_location)
         """
 
     def delete_vod_source(self, *, SourceLocationName: str, VodSourceName: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/mediatailor.html#MediaTailor.Client.delete_vod_source)
+        Deletes a specific VOD source in a specific source location.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Client.delete_vod_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#delete_vod_source)
         """
 
-    def describe_channel(self, *, ChannelName: str) -> DescribeChannelResponseTypeDef:
+    def describe_channel(self, *, ChannelName: str) -> DescribeChannelResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/mediatailor.html#MediaTailor.Client.describe_channel)
+        Describes the properties of a specific channel.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Client.describe_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#describe_channel)
         """
 
     def describe_program(
         self, *, ChannelName: str, ProgramName: str
-    ) -> DescribeProgramResponseTypeDef:
+    ) -> DescribeProgramResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/mediatailor.html#MediaTailor.Client.describe_program)
+        Retrieves the properties of the requested program.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Client.describe_program)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#describe_program)
         """
 
     def describe_source_location(
         self, *, SourceLocationName: str
-    ) -> DescribeSourceLocationResponseTypeDef:
+    ) -> DescribeSourceLocationResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/mediatailor.html#MediaTailor.Client.describe_source_location)
+        Retrieves the properties of the requested source location.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Client.describe_source_location)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#describe_source_location)
         """
 
     def describe_vod_source(
         self, *, SourceLocationName: str, VodSourceName: str
-    ) -> DescribeVodSourceResponseTypeDef:
+    ) -> DescribeVodSourceResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/mediatailor.html#MediaTailor.Client.describe_vod_source)
+        Provides details about a specific VOD source in a specific source location.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Client.describe_vod_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#describe_vod_source)
         """
 
@@ -226,13 +256,17 @@ class MediaTailorClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/mediatailor.html#MediaTailor.Client.generate_presigned_url)
+        Generate a presigned url given a client, its method, and arguments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#generate_presigned_url)
         """
 
-    def get_channel_policy(self, *, ChannelName: str) -> GetChannelPolicyResponseTypeDef:
+    def get_channel_policy(self, *, ChannelName: str) -> GetChannelPolicyResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/mediatailor.html#MediaTailor.Client.get_channel_policy)
+        Retrieves information about a channel's IAM policy.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Client.get_channel_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#get_channel_policy)
         """
 
@@ -243,59 +277,81 @@ class MediaTailorClient:
         DurationMinutes: str = None,
         MaxResults: int = None,
         NextToken: str = None
-    ) -> GetChannelScheduleResponseTypeDef:
+    ) -> GetChannelScheduleResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/mediatailor.html#MediaTailor.Client.get_channel_schedule)
+        Retrieves information about your channel's schedule.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Client.get_channel_schedule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#get_channel_schedule)
         """
 
-    def get_playback_configuration(self, *, Name: str) -> GetPlaybackConfigurationResponseTypeDef:
+    def get_playback_configuration(
+        self, *, Name: str
+    ) -> GetPlaybackConfigurationResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/mediatailor.html#MediaTailor.Client.get_playback_configuration)
+        Returns the playback configuration for the specified name.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Client.get_playback_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#get_playback_configuration)
         """
 
     def list_channels(
         self, *, MaxResults: int = None, NextToken: str = None
-    ) -> ListChannelsResponseTypeDef:
+    ) -> ListChannelsResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/mediatailor.html#MediaTailor.Client.list_channels)
+        Retrieves a list of channels that are associated with this account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Client.list_channels)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#list_channels)
         """
 
     def list_playback_configurations(
         self, *, MaxResults: int = None, NextToken: str = None
-    ) -> ListPlaybackConfigurationsResponseTypeDef:
+    ) -> ListPlaybackConfigurationsResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/mediatailor.html#MediaTailor.Client.list_playback_configurations)
+        Returns a list of the playback configurations defined in AWS Elemental
+        MediaTailor.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Client.list_playback_configurations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#list_playback_configurations)
         """
 
     def list_source_locations(
         self, *, MaxResults: int = None, NextToken: str = None
-    ) -> ListSourceLocationsResponseTypeDef:
+    ) -> ListSourceLocationsResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/mediatailor.html#MediaTailor.Client.list_source_locations)
+        Retrieves a list of source locations.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Client.list_source_locations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#list_source_locations)
         """
 
-    def list_tags_for_resource(self, *, ResourceArn: str) -> ListTagsForResourceResponseTypeDef:
+    def list_tags_for_resource(
+        self, *, ResourceArn: str
+    ) -> ListTagsForResourceResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/mediatailor.html#MediaTailor.Client.list_tags_for_resource)
+        Returns a list of the tags assigned to the specified playback configuration
+        resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#list_tags_for_resource)
         """
 
     def list_vod_sources(
         self, *, SourceLocationName: str, MaxResults: int = None, NextToken: str = None
-    ) -> ListVodSourcesResponseTypeDef:
+    ) -> ListVodSourcesResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/mediatailor.html#MediaTailor.Client.list_vod_sources)
+        Lists all the VOD sources in a source location.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Client.list_vod_sources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#list_vod_sources)
         """
 
     def put_channel_policy(self, *, ChannelName: str, Policy: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/mediatailor.html#MediaTailor.Client.put_channel_policy)
+        Creates an IAM policy for the channel.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Client.put_channel_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#put_channel_policy)
         """
 
@@ -307,7 +363,7 @@ class MediaTailorClient:
         Bumper: "BumperTypeDef" = None,
         CdnConfiguration: "CdnConfigurationTypeDef" = None,
         ConfigurationAliases: Dict[str, Dict[str, str]] = None,
-        DashConfiguration: DashConfigurationForPutTypeDef = None,
+        DashConfiguration: "DashConfigurationForPutTypeDef" = None,
         LivePreRollConfiguration: "LivePreRollConfigurationTypeDef" = None,
         ManifestProcessingRules: "ManifestProcessingRulesTypeDef" = None,
         Name: str = None,
@@ -316,41 +372,53 @@ class MediaTailorClient:
         Tags: Dict[str, str] = None,
         TranscodeProfileName: str = None,
         VideoContentSourceUrl: str = None
-    ) -> PutPlaybackConfigurationResponseTypeDef:
+    ) -> PutPlaybackConfigurationResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/mediatailor.html#MediaTailor.Client.put_playback_configuration)
+        Adds a new playback configuration to AWS Elemental MediaTailor.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Client.put_playback_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#put_playback_configuration)
         """
 
     def start_channel(self, *, ChannelName: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/mediatailor.html#MediaTailor.Client.start_channel)
+        Starts a specific channel.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Client.start_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#start_channel)
         """
 
     def stop_channel(self, *, ChannelName: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/mediatailor.html#MediaTailor.Client.stop_channel)
+        Stops a specific channel.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Client.stop_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#stop_channel)
         """
 
     def tag_resource(self, *, ResourceArn: str, Tags: Dict[str, str]) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/mediatailor.html#MediaTailor.Client.tag_resource)
+        Adds tags to the specified playback configuration resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#tag_resource)
         """
 
     def untag_resource(self, *, ResourceArn: str, TagKeys: List[str]) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/mediatailor.html#MediaTailor.Client.untag_resource)
+        Removes tags from the specified playback configuration resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#untag_resource)
         """
 
     def update_channel(
-        self, *, ChannelName: str, Outputs: List[RequestOutputItemTypeDef]
-    ) -> UpdateChannelResponseTypeDef:
+        self, *, ChannelName: str, Outputs: List["RequestOutputItemTypeDef"]
+    ) -> UpdateChannelResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/mediatailor.html#MediaTailor.Client.update_channel)
+        Updates an existing channel.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Client.update_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#update_channel)
         """
 
@@ -361,9 +429,11 @@ class MediaTailorClient:
         SourceLocationName: str,
         AccessConfiguration: "AccessConfigurationTypeDef" = None,
         DefaultSegmentDeliveryConfiguration: "DefaultSegmentDeliveryConfigurationTypeDef" = None
-    ) -> UpdateSourceLocationResponseTypeDef:
+    ) -> UpdateSourceLocationResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/mediatailor.html#MediaTailor.Client.update_source_location)
+        Updates a source location on a specific channel.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Client.update_source_location)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#update_source_location)
         """
 
@@ -373,9 +443,11 @@ class MediaTailorClient:
         HttpPackageConfigurations: List["HttpPackageConfigurationTypeDef"],
         SourceLocationName: str,
         VodSourceName: str
-    ) -> UpdateVodSourceResponseTypeDef:
+    ) -> UpdateVodSourceResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/mediatailor.html#MediaTailor.Client.update_vod_source)
+        Updates a specific VOD source in a specific source location.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Client.update_vod_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#update_vod_source)
         """
 
@@ -384,13 +456,15 @@ class MediaTailorClient:
         self, operation_name: Literal["get_channel_schedule"]
     ) -> GetChannelSchedulePaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/mediatailor.html#MediaTailor.Paginator.GetChannelSchedule)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#getchannelschedulepaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Paginator.GetChannelSchedule)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#getchannelschedulepaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_channels"]) -> ListChannelsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/mediatailor.html#MediaTailor.Paginator.ListChannels)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listchannelspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Paginator.ListChannels)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listchannelspaginator)
         """
 
     @overload
@@ -398,7 +472,8 @@ class MediaTailorClient:
         self, operation_name: Literal["list_playback_configurations"]
     ) -> ListPlaybackConfigurationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/mediatailor.html#MediaTailor.Paginator.ListPlaybackConfigurations)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listplaybackconfigurationspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Paginator.ListPlaybackConfigurations)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listplaybackconfigurationspaginator)
         """
 
     @overload
@@ -406,11 +481,13 @@ class MediaTailorClient:
         self, operation_name: Literal["list_source_locations"]
     ) -> ListSourceLocationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/mediatailor.html#MediaTailor.Paginator.ListSourceLocations)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listsourcelocationspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Paginator.ListSourceLocations)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listsourcelocationspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_vod_sources"]) -> ListVodSourcesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/mediatailor.html#MediaTailor.Paginator.ListVodSources)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listvodsourcespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/mediatailor.html#MediaTailor.Paginator.ListVodSources)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listvodsourcespaginator)
         """
