@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Dict, List
+from typing import Any, Dict, List
 
 from .literals import (
     AccessTypeType,
@@ -42,36 +42,61 @@ __all__ = (
     "BumperTypeDef",
     "CdnConfigurationTypeDef",
     "ChannelTypeDef",
-    "CreateChannelResponseTypeDef",
-    "CreateProgramResponseTypeDef",
-    "CreateSourceLocationResponseTypeDef",
-    "CreateVodSourceResponseTypeDef",
+    "CreateChannelRequestTypeDef",
+    "CreateChannelResponseResponseTypeDef",
+    "CreateProgramRequestTypeDef",
+    "CreateProgramResponseResponseTypeDef",
+    "CreateSourceLocationRequestTypeDef",
+    "CreateSourceLocationResponseResponseTypeDef",
+    "CreateVodSourceRequestTypeDef",
+    "CreateVodSourceResponseResponseTypeDef",
     "DashConfigurationForPutTypeDef",
     "DashConfigurationTypeDef",
     "DashPlaylistSettingsTypeDef",
     "DefaultSegmentDeliveryConfigurationTypeDef",
-    "DescribeChannelResponseTypeDef",
-    "DescribeProgramResponseTypeDef",
-    "DescribeSourceLocationResponseTypeDef",
-    "DescribeVodSourceResponseTypeDef",
-    "GetChannelPolicyResponseTypeDef",
-    "GetChannelScheduleResponseTypeDef",
-    "GetPlaybackConfigurationResponseTypeDef",
+    "DeleteChannelPolicyRequestTypeDef",
+    "DeleteChannelRequestTypeDef",
+    "DeletePlaybackConfigurationRequestTypeDef",
+    "DeleteProgramRequestTypeDef",
+    "DeleteSourceLocationRequestTypeDef",
+    "DeleteVodSourceRequestTypeDef",
+    "DescribeChannelRequestTypeDef",
+    "DescribeChannelResponseResponseTypeDef",
+    "DescribeProgramRequestTypeDef",
+    "DescribeProgramResponseResponseTypeDef",
+    "DescribeSourceLocationRequestTypeDef",
+    "DescribeSourceLocationResponseResponseTypeDef",
+    "DescribeVodSourceRequestTypeDef",
+    "DescribeVodSourceResponseResponseTypeDef",
+    "GetChannelPolicyRequestTypeDef",
+    "GetChannelPolicyResponseResponseTypeDef",
+    "GetChannelScheduleRequestTypeDef",
+    "GetChannelScheduleResponseResponseTypeDef",
+    "GetPlaybackConfigurationRequestTypeDef",
+    "GetPlaybackConfigurationResponseResponseTypeDef",
     "HlsConfigurationTypeDef",
     "HlsPlaylistSettingsTypeDef",
     "HttpConfigurationTypeDef",
     "HttpPackageConfigurationTypeDef",
-    "ListChannelsResponseTypeDef",
-    "ListPlaybackConfigurationsResponseTypeDef",
-    "ListSourceLocationsResponseTypeDef",
-    "ListTagsForResourceResponseTypeDef",
-    "ListVodSourcesResponseTypeDef",
+    "ListChannelsRequestTypeDef",
+    "ListChannelsResponseResponseTypeDef",
+    "ListPlaybackConfigurationsRequestTypeDef",
+    "ListPlaybackConfigurationsResponseResponseTypeDef",
+    "ListSourceLocationsRequestTypeDef",
+    "ListSourceLocationsResponseResponseTypeDef",
+    "ListTagsForResourceRequestTypeDef",
+    "ListTagsForResourceResponseResponseTypeDef",
+    "ListVodSourcesRequestTypeDef",
+    "ListVodSourcesResponseResponseTypeDef",
     "LivePreRollConfigurationTypeDef",
     "ManifestProcessingRulesTypeDef",
     "PaginatorConfigTypeDef",
     "PlaybackConfigurationTypeDef",
-    "PutPlaybackConfigurationResponseTypeDef",
+    "PutChannelPolicyRequestTypeDef",
+    "PutPlaybackConfigurationRequestTypeDef",
+    "PutPlaybackConfigurationResponseResponseTypeDef",
     "RequestOutputItemTypeDef",
+    "ResponseMetadataTypeDef",
     "ResponseOutputItemTypeDef",
     "ScheduleAdBreakTypeDef",
     "ScheduleConfigurationTypeDef",
@@ -80,10 +105,17 @@ __all__ = (
     "SlateSourceTypeDef",
     "SourceLocationTypeDef",
     "SpliceInsertMessageTypeDef",
+    "StartChannelRequestTypeDef",
+    "StopChannelRequestTypeDef",
+    "TagResourceRequestTypeDef",
     "TransitionTypeDef",
-    "UpdateChannelResponseTypeDef",
-    "UpdateSourceLocationResponseTypeDef",
-    "UpdateVodSourceResponseTypeDef",
+    "UntagResourceRequestTypeDef",
+    "UpdateChannelRequestTypeDef",
+    "UpdateChannelResponseResponseTypeDef",
+    "UpdateSourceLocationRequestTypeDef",
+    "UpdateSourceLocationResponseResponseTypeDef",
+    "UpdateVodSourceRequestTypeDef",
+    "UpdateVodSourceResponseResponseTypeDef",
     "VodSourceTypeDef",
 )
 
@@ -167,8 +199,31 @@ class ChannelTypeDef(_RequiredChannelTypeDef, _OptionalChannelTypeDef):
     pass
 
 
-CreateChannelResponseTypeDef = TypedDict(
-    "CreateChannelResponseTypeDef",
+_RequiredCreateChannelRequestTypeDef = TypedDict(
+    "_RequiredCreateChannelRequestTypeDef",
+    {
+        "ChannelName": str,
+        "Outputs": List["RequestOutputItemTypeDef"],
+        "PlaybackMode": Literal["LOOP"],
+    },
+)
+_OptionalCreateChannelRequestTypeDef = TypedDict(
+    "_OptionalCreateChannelRequestTypeDef",
+    {
+        "Tags": Dict[str, str],
+    },
+    total=False,
+)
+
+
+class CreateChannelRequestTypeDef(
+    _RequiredCreateChannelRequestTypeDef, _OptionalCreateChannelRequestTypeDef
+):
+    pass
+
+
+CreateChannelResponseResponseTypeDef = TypedDict(
+    "CreateChannelResponseResponseTypeDef",
     {
         "Arn": str,
         "ChannelName": str,
@@ -178,12 +233,37 @@ CreateChannelResponseTypeDef = TypedDict(
         "Outputs": List["ResponseOutputItemTypeDef"],
         "PlaybackMode": str,
         "Tags": Dict[str, str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredCreateProgramRequestTypeDef = TypedDict(
+    "_RequiredCreateProgramRequestTypeDef",
+    {
+        "ChannelName": str,
+        "ProgramName": str,
+        "ScheduleConfiguration": "ScheduleConfigurationTypeDef",
+        "SourceLocationName": str,
+        "VodSourceName": str,
+    },
+)
+_OptionalCreateProgramRequestTypeDef = TypedDict(
+    "_OptionalCreateProgramRequestTypeDef",
+    {
+        "AdBreaks": List["AdBreakTypeDef"],
     },
     total=False,
 )
 
-CreateProgramResponseTypeDef = TypedDict(
-    "CreateProgramResponseTypeDef",
+
+class CreateProgramRequestTypeDef(
+    _RequiredCreateProgramRequestTypeDef, _OptionalCreateProgramRequestTypeDef
+):
+    pass
+
+
+CreateProgramResponseResponseTypeDef = TypedDict(
+    "CreateProgramResponseResponseTypeDef",
     {
         "AdBreaks": List["AdBreakTypeDef"],
         "Arn": str,
@@ -192,12 +272,36 @@ CreateProgramResponseTypeDef = TypedDict(
         "ProgramName": str,
         "SourceLocationName": str,
         "VodSourceName": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredCreateSourceLocationRequestTypeDef = TypedDict(
+    "_RequiredCreateSourceLocationRequestTypeDef",
+    {
+        "HttpConfiguration": "HttpConfigurationTypeDef",
+        "SourceLocationName": str,
+    },
+)
+_OptionalCreateSourceLocationRequestTypeDef = TypedDict(
+    "_OptionalCreateSourceLocationRequestTypeDef",
+    {
+        "AccessConfiguration": "AccessConfigurationTypeDef",
+        "DefaultSegmentDeliveryConfiguration": "DefaultSegmentDeliveryConfigurationTypeDef",
+        "Tags": Dict[str, str],
     },
     total=False,
 )
 
-CreateSourceLocationResponseTypeDef = TypedDict(
-    "CreateSourceLocationResponseTypeDef",
+
+class CreateSourceLocationRequestTypeDef(
+    _RequiredCreateSourceLocationRequestTypeDef, _OptionalCreateSourceLocationRequestTypeDef
+):
+    pass
+
+
+CreateSourceLocationResponseResponseTypeDef = TypedDict(
+    "CreateSourceLocationResponseResponseTypeDef",
     {
         "AccessConfiguration": "AccessConfigurationTypeDef",
         "Arn": str,
@@ -207,12 +311,35 @@ CreateSourceLocationResponseTypeDef = TypedDict(
         "LastModifiedTime": datetime,
         "SourceLocationName": str,
         "Tags": Dict[str, str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredCreateVodSourceRequestTypeDef = TypedDict(
+    "_RequiredCreateVodSourceRequestTypeDef",
+    {
+        "HttpPackageConfigurations": List["HttpPackageConfigurationTypeDef"],
+        "SourceLocationName": str,
+        "VodSourceName": str,
+    },
+)
+_OptionalCreateVodSourceRequestTypeDef = TypedDict(
+    "_OptionalCreateVodSourceRequestTypeDef",
+    {
+        "Tags": Dict[str, str],
     },
     total=False,
 )
 
-CreateVodSourceResponseTypeDef = TypedDict(
-    "CreateVodSourceResponseTypeDef",
+
+class CreateVodSourceRequestTypeDef(
+    _RequiredCreateVodSourceRequestTypeDef, _OptionalCreateVodSourceRequestTypeDef
+):
+    pass
+
+
+CreateVodSourceResponseResponseTypeDef = TypedDict(
+    "CreateVodSourceResponseResponseTypeDef",
     {
         "Arn": str,
         "CreationTime": datetime,
@@ -221,8 +348,8 @@ CreateVodSourceResponseTypeDef = TypedDict(
         "SourceLocationName": str,
         "Tags": Dict[str, str],
         "VodSourceName": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 DashConfigurationForPutTypeDef = TypedDict(
@@ -263,8 +390,59 @@ DefaultSegmentDeliveryConfigurationTypeDef = TypedDict(
     total=False,
 )
 
-DescribeChannelResponseTypeDef = TypedDict(
-    "DescribeChannelResponseTypeDef",
+DeleteChannelPolicyRequestTypeDef = TypedDict(
+    "DeleteChannelPolicyRequestTypeDef",
+    {
+        "ChannelName": str,
+    },
+)
+
+DeleteChannelRequestTypeDef = TypedDict(
+    "DeleteChannelRequestTypeDef",
+    {
+        "ChannelName": str,
+    },
+)
+
+DeletePlaybackConfigurationRequestTypeDef = TypedDict(
+    "DeletePlaybackConfigurationRequestTypeDef",
+    {
+        "Name": str,
+    },
+)
+
+DeleteProgramRequestTypeDef = TypedDict(
+    "DeleteProgramRequestTypeDef",
+    {
+        "ChannelName": str,
+        "ProgramName": str,
+    },
+)
+
+DeleteSourceLocationRequestTypeDef = TypedDict(
+    "DeleteSourceLocationRequestTypeDef",
+    {
+        "SourceLocationName": str,
+    },
+)
+
+DeleteVodSourceRequestTypeDef = TypedDict(
+    "DeleteVodSourceRequestTypeDef",
+    {
+        "SourceLocationName": str,
+        "VodSourceName": str,
+    },
+)
+
+DescribeChannelRequestTypeDef = TypedDict(
+    "DescribeChannelRequestTypeDef",
+    {
+        "ChannelName": str,
+    },
+)
+
+DescribeChannelResponseResponseTypeDef = TypedDict(
+    "DescribeChannelResponseResponseTypeDef",
     {
         "Arn": str,
         "ChannelName": str,
@@ -274,12 +452,20 @@ DescribeChannelResponseTypeDef = TypedDict(
         "Outputs": List["ResponseOutputItemTypeDef"],
         "PlaybackMode": str,
         "Tags": Dict[str, str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-DescribeProgramResponseTypeDef = TypedDict(
-    "DescribeProgramResponseTypeDef",
+DescribeProgramRequestTypeDef = TypedDict(
+    "DescribeProgramRequestTypeDef",
+    {
+        "ChannelName": str,
+        "ProgramName": str,
+    },
+)
+
+DescribeProgramResponseResponseTypeDef = TypedDict(
+    "DescribeProgramResponseResponseTypeDef",
     {
         "AdBreaks": List["AdBreakTypeDef"],
         "Arn": str,
@@ -288,12 +474,19 @@ DescribeProgramResponseTypeDef = TypedDict(
         "ProgramName": str,
         "SourceLocationName": str,
         "VodSourceName": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-DescribeSourceLocationResponseTypeDef = TypedDict(
-    "DescribeSourceLocationResponseTypeDef",
+DescribeSourceLocationRequestTypeDef = TypedDict(
+    "DescribeSourceLocationRequestTypeDef",
+    {
+        "SourceLocationName": str,
+    },
+)
+
+DescribeSourceLocationResponseResponseTypeDef = TypedDict(
+    "DescribeSourceLocationResponseResponseTypeDef",
     {
         "AccessConfiguration": "AccessConfigurationTypeDef",
         "Arn": str,
@@ -303,12 +496,20 @@ DescribeSourceLocationResponseTypeDef = TypedDict(
         "LastModifiedTime": datetime,
         "SourceLocationName": str,
         "Tags": Dict[str, str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-DescribeVodSourceResponseTypeDef = TypedDict(
-    "DescribeVodSourceResponseTypeDef",
+DescribeVodSourceRequestTypeDef = TypedDict(
+    "DescribeVodSourceRequestTypeDef",
+    {
+        "SourceLocationName": str,
+        "VodSourceName": str,
+    },
+)
+
+DescribeVodSourceResponseResponseTypeDef = TypedDict(
+    "DescribeVodSourceResponseResponseTypeDef",
     {
         "Arn": str,
         "CreationTime": datetime,
@@ -317,29 +518,66 @@ DescribeVodSourceResponseTypeDef = TypedDict(
         "SourceLocationName": str,
         "Tags": Dict[str, str],
         "VodSourceName": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-GetChannelPolicyResponseTypeDef = TypedDict(
-    "GetChannelPolicyResponseTypeDef",
+GetChannelPolicyRequestTypeDef = TypedDict(
+    "GetChannelPolicyRequestTypeDef",
+    {
+        "ChannelName": str,
+    },
+)
+
+GetChannelPolicyResponseResponseTypeDef = TypedDict(
+    "GetChannelPolicyResponseResponseTypeDef",
     {
         "Policy": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-GetChannelScheduleResponseTypeDef = TypedDict(
-    "GetChannelScheduleResponseTypeDef",
+_RequiredGetChannelScheduleRequestTypeDef = TypedDict(
+    "_RequiredGetChannelScheduleRequestTypeDef",
     {
-        "Items": List["ScheduleEntryTypeDef"],
+        "ChannelName": str,
+    },
+)
+_OptionalGetChannelScheduleRequestTypeDef = TypedDict(
+    "_OptionalGetChannelScheduleRequestTypeDef",
+    {
+        "DurationMinutes": str,
+        "MaxResults": int,
         "NextToken": str,
     },
     total=False,
 )
 
-GetPlaybackConfigurationResponseTypeDef = TypedDict(
-    "GetPlaybackConfigurationResponseTypeDef",
+
+class GetChannelScheduleRequestTypeDef(
+    _RequiredGetChannelScheduleRequestTypeDef, _OptionalGetChannelScheduleRequestTypeDef
+):
+    pass
+
+
+GetChannelScheduleResponseResponseTypeDef = TypedDict(
+    "GetChannelScheduleResponseResponseTypeDef",
+    {
+        "Items": List["ScheduleEntryTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+GetPlaybackConfigurationRequestTypeDef = TypedDict(
+    "GetPlaybackConfigurationRequestTypeDef",
+    {
+        "Name": str,
+    },
+)
+
+GetPlaybackConfigurationResponseResponseTypeDef = TypedDict(
+    "GetPlaybackConfigurationResponseResponseTypeDef",
     {
         "AdDecisionServerUrl": str,
         "AvailSuppression": "AvailSuppressionTypeDef",
@@ -359,8 +597,8 @@ GetPlaybackConfigurationResponseTypeDef = TypedDict(
         "Tags": Dict[str, str],
         "TranscodeProfileName": str,
         "VideoContentSourceUrl": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 HlsConfigurationTypeDef = TypedDict(
@@ -395,50 +633,106 @@ HttpPackageConfigurationTypeDef = TypedDict(
     },
 )
 
-ListChannelsResponseTypeDef = TypedDict(
-    "ListChannelsResponseTypeDef",
+ListChannelsRequestTypeDef = TypedDict(
+    "ListChannelsRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+ListChannelsResponseResponseTypeDef = TypedDict(
+    "ListChannelsResponseResponseTypeDef",
     {
         "Items": List["ChannelTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListPlaybackConfigurationsRequestTypeDef = TypedDict(
+    "ListPlaybackConfigurationsRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
     },
     total=False,
 )
 
-ListPlaybackConfigurationsResponseTypeDef = TypedDict(
-    "ListPlaybackConfigurationsResponseTypeDef",
+ListPlaybackConfigurationsResponseResponseTypeDef = TypedDict(
+    "ListPlaybackConfigurationsResponseResponseTypeDef",
     {
         "Items": List["PlaybackConfigurationTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListSourceLocationsRequestTypeDef = TypedDict(
+    "ListSourceLocationsRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
     },
     total=False,
 )
 
-ListSourceLocationsResponseTypeDef = TypedDict(
-    "ListSourceLocationsResponseTypeDef",
+ListSourceLocationsResponseResponseTypeDef = TypedDict(
+    "ListSourceLocationsResponseResponseTypeDef",
     {
         "Items": List["SourceLocationTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef",
+ListTagsForResourceRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestTypeDef",
+    {
+        "ResourceArn": str,
+    },
+)
+
+ListTagsForResourceResponseResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseResponseTypeDef",
     {
         "Tags": Dict[str, str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-ListVodSourcesResponseTypeDef = TypedDict(
-    "ListVodSourcesResponseTypeDef",
+_RequiredListVodSourcesRequestTypeDef = TypedDict(
+    "_RequiredListVodSourcesRequestTypeDef",
     {
-        "Items": List["VodSourceTypeDef"],
+        "SourceLocationName": str,
+    },
+)
+_OptionalListVodSourcesRequestTypeDef = TypedDict(
+    "_OptionalListVodSourcesRequestTypeDef",
+    {
+        "MaxResults": int,
         "NextToken": str,
     },
     total=False,
 )
 
+
+class ListVodSourcesRequestTypeDef(
+    _RequiredListVodSourcesRequestTypeDef, _OptionalListVodSourcesRequestTypeDef
+):
+    pass
+
+
+ListVodSourcesResponseResponseTypeDef = TypedDict(
+    "ListVodSourcesResponseResponseTypeDef",
+    {
+        "Items": List["VodSourceTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 LivePreRollConfigurationTypeDef = TypedDict(
     "LivePreRollConfigurationTypeDef",
     {
@@ -491,8 +785,37 @@ PlaybackConfigurationTypeDef = TypedDict(
     total=False,
 )
 
-PutPlaybackConfigurationResponseTypeDef = TypedDict(
-    "PutPlaybackConfigurationResponseTypeDef",
+PutChannelPolicyRequestTypeDef = TypedDict(
+    "PutChannelPolicyRequestTypeDef",
+    {
+        "ChannelName": str,
+        "Policy": str,
+    },
+)
+
+PutPlaybackConfigurationRequestTypeDef = TypedDict(
+    "PutPlaybackConfigurationRequestTypeDef",
+    {
+        "AdDecisionServerUrl": str,
+        "AvailSuppression": "AvailSuppressionTypeDef",
+        "Bumper": "BumperTypeDef",
+        "CdnConfiguration": "CdnConfigurationTypeDef",
+        "ConfigurationAliases": Dict[str, Dict[str, str]],
+        "DashConfiguration": "DashConfigurationForPutTypeDef",
+        "LivePreRollConfiguration": "LivePreRollConfigurationTypeDef",
+        "ManifestProcessingRules": "ManifestProcessingRulesTypeDef",
+        "Name": str,
+        "PersonalizationThresholdSeconds": int,
+        "SlateAdUrl": str,
+        "Tags": Dict[str, str],
+        "TranscodeProfileName": str,
+        "VideoContentSourceUrl": str,
+    },
+    total=False,
+)
+
+PutPlaybackConfigurationResponseResponseTypeDef = TypedDict(
+    "PutPlaybackConfigurationResponseResponseTypeDef",
     {
         "AdDecisionServerUrl": str,
         "AvailSuppression": "AvailSuppressionTypeDef",
@@ -512,8 +835,8 @@ PutPlaybackConfigurationResponseTypeDef = TypedDict(
         "Tags": Dict[str, str],
         "TranscodeProfileName": str,
         "VideoContentSourceUrl": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 _RequiredRequestOutputItemTypeDef = TypedDict(
@@ -539,6 +862,17 @@ class RequestOutputItemTypeDef(
     pass
 
 
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, Any],
+        "RetryAttempts": int,
+    },
+)
+
 _RequiredResponseOutputItemTypeDef = TypedDict(
     "_RequiredResponseOutputItemTypeDef",
     {
@@ -661,6 +995,28 @@ SpliceInsertMessageTypeDef = TypedDict(
     total=False,
 )
 
+StartChannelRequestTypeDef = TypedDict(
+    "StartChannelRequestTypeDef",
+    {
+        "ChannelName": str,
+    },
+)
+
+StopChannelRequestTypeDef = TypedDict(
+    "StopChannelRequestTypeDef",
+    {
+        "ChannelName": str,
+    },
+)
+
+TagResourceRequestTypeDef = TypedDict(
+    "TagResourceRequestTypeDef",
+    {
+        "ResourceArn": str,
+        "Tags": Dict[str, str],
+    },
+)
+
 _RequiredTransitionTypeDef = TypedDict(
     "_RequiredTransitionTypeDef",
     {
@@ -681,8 +1037,24 @@ class TransitionTypeDef(_RequiredTransitionTypeDef, _OptionalTransitionTypeDef):
     pass
 
 
-UpdateChannelResponseTypeDef = TypedDict(
-    "UpdateChannelResponseTypeDef",
+UntagResourceRequestTypeDef = TypedDict(
+    "UntagResourceRequestTypeDef",
+    {
+        "ResourceArn": str,
+        "TagKeys": List[str],
+    },
+)
+
+UpdateChannelRequestTypeDef = TypedDict(
+    "UpdateChannelRequestTypeDef",
+    {
+        "ChannelName": str,
+        "Outputs": List["RequestOutputItemTypeDef"],
+    },
+)
+
+UpdateChannelResponseResponseTypeDef = TypedDict(
+    "UpdateChannelResponseResponseTypeDef",
     {
         "Arn": str,
         "ChannelName": str,
@@ -692,12 +1064,35 @@ UpdateChannelResponseTypeDef = TypedDict(
         "Outputs": List["ResponseOutputItemTypeDef"],
         "PlaybackMode": str,
         "Tags": Dict[str, str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredUpdateSourceLocationRequestTypeDef = TypedDict(
+    "_RequiredUpdateSourceLocationRequestTypeDef",
+    {
+        "HttpConfiguration": "HttpConfigurationTypeDef",
+        "SourceLocationName": str,
+    },
+)
+_OptionalUpdateSourceLocationRequestTypeDef = TypedDict(
+    "_OptionalUpdateSourceLocationRequestTypeDef",
+    {
+        "AccessConfiguration": "AccessConfigurationTypeDef",
+        "DefaultSegmentDeliveryConfiguration": "DefaultSegmentDeliveryConfigurationTypeDef",
     },
     total=False,
 )
 
-UpdateSourceLocationResponseTypeDef = TypedDict(
-    "UpdateSourceLocationResponseTypeDef",
+
+class UpdateSourceLocationRequestTypeDef(
+    _RequiredUpdateSourceLocationRequestTypeDef, _OptionalUpdateSourceLocationRequestTypeDef
+):
+    pass
+
+
+UpdateSourceLocationResponseResponseTypeDef = TypedDict(
+    "UpdateSourceLocationResponseResponseTypeDef",
     {
         "AccessConfiguration": "AccessConfigurationTypeDef",
         "Arn": str,
@@ -707,12 +1102,21 @@ UpdateSourceLocationResponseTypeDef = TypedDict(
         "LastModifiedTime": datetime,
         "SourceLocationName": str,
         "Tags": Dict[str, str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-UpdateVodSourceResponseTypeDef = TypedDict(
-    "UpdateVodSourceResponseTypeDef",
+UpdateVodSourceRequestTypeDef = TypedDict(
+    "UpdateVodSourceRequestTypeDef",
+    {
+        "HttpPackageConfigurations": List["HttpPackageConfigurationTypeDef"],
+        "SourceLocationName": str,
+        "VodSourceName": str,
+    },
+)
+
+UpdateVodSourceResponseResponseTypeDef = TypedDict(
+    "UpdateVodSourceResponseResponseTypeDef",
     {
         "Arn": str,
         "CreationTime": datetime,
@@ -721,8 +1125,8 @@ UpdateVodSourceResponseTypeDef = TypedDict(
         "SourceLocationName": str,
         "Tags": Dict[str, str],
         "VodSourceName": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 _RequiredVodSourceTypeDef = TypedDict(
